SF.net SVN: phpwiki:[11180] trunk

vargenau--- via phpwiki-checkins <[email protected]> Sun, 09 Mar 2025 16:47:47 +0000
Newsgroups gmane.comp.web.wiki.phpwiki.checkins
Message-ID <[email protected]>
Revision: 11180
          http://sourceforge.net/p/phpwiki/code/11180
Author:   vargenau
Date:     2025-03-09 16:47:46 +0000 (Sun, 09 Mar 2025)
Log Message:
-----------
depreciated --> deprecated

Modified Paths:
--------------
    trunk/lib/ErrorManager.php
    trunk/pgsrc/ReleaseNotes
    trunk/themes/default/phpwiki-common.css

Modified: trunk/lib/ErrorManager.php
===================================================================
--- trunk/pgsrc/ReleaseNotes	2025-03-02 22:30:41 UTC (rev 11179)
+++ trunk/pgsrc/ReleaseNotes	2025-03-09 16:47:46 UTC (rev 11180)
@@ -33,10 +33,10 @@
   ~PhotoAlbumPlugin. Removed url of defunct example website that broke
   PhpWikiManual.
 * **Important bugfix for PHP 8.3 and newer:** Fixed garbled display of pages
-  due to depreciated errors. Also try harder to suppress depreciated errors on
-  all PHP versions. Set ##DEBUG=2## in ##config.ini## to view depreciated
+  due to deprecated errors. Also try harder to suppress deprecated errors on
+  all PHP versions. Set ##DEBUG=2## in ##config.ini## to view deprecated
   errors, and ##DEBUG=1## for basic errors. Added hooks for css formatting of
-  depreciated errors.
+  deprecated errors.
 * Improvements and bugfixes to loading and saving pages to filedumps:
   - fixed download of individual dump files stalling in chrome (must always
     click resume).

Modified: trunk/themes/default/phpwiki-common.css
===================================================================
--- trunk/themes/default/phpwiki-common.css	2025-03-02 22:30:41 UTC (rev 11179)
+++ trunk/themes/default/phpwiki-common.css	2025-03-09 16:47:46 UTC (rev 11180)
@@ -66,7 +66,7 @@
 
 /* Banners ============================================================ */
 
-.success, .feedback, .warning, .warning_msg, .error, .information, .depreciated {
+.success, .feedback, .warning, .warning_msg, .error, .information, .deprecated {
     color: black;
     padding-left: 0.5em;
     padding-right: 0.5em;
@@ -98,13 +98,13 @@
     padding: 1ex;
 }
 
-.depreciated {
+.deprecated {
     border-color: #bbbbbb;
     background-color: white;
     padding-top: 0.00ex;
     padding-bottom: 0.1ex;
 }
-.depreciated p {
+.deprecated p {
     font-family: monospace;
 }
 

This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
--- trunk/lib/ErrorManager.php	2025-03-02 22:30:41 UTC (rev 11179)
+++ trunk/lib/ErrorManager.php	2025-03-09 16:47:46 UTC (rev 11180)
@@ -45,7 +45,7 @@
    This also means that the ability to execute custom callbacks is also
    deprecated, with no replacement functionality provided.
    https://php.watch/versions/8.3/assert-multiple-deprecations
-   Hide depreciated errors unless DEBUG=2 because they output compressed text
+   Hide deprecated errors unless DEBUG=2 because they output compressed text
    before all headers have been sent, resulting in a garbled page.
    All code using assertions will have to be rewritten for php9.
  */
@@ -78,11 +78,11 @@
     /**
      * As this is a singleton class, you should never call this.
      */
     //fixed depreciated dynamic typing
     public $_handlers;
     public $_fatal_handler;
     public $_postpone_mask;
-    public $_postponed_errors;//ok
+    public $_postponed_errors; // ok
 
     public function __construct()
     {
@@ -514,7 +514,7 @@
         if ($this->isNotice()) {
             return 'hint';
         } elseif ($this->isDepreciated()) {
-            return 'depreciated';
+            return 'deprecated';
         } elseif ($this->isWarning()) {
             return 'warning';
         } else {
@@ -527,7 +527,7 @@
         if ($this->isNotice()) {
             return 'Notice';
         } elseif ($this->isDepreciated()) {
-            return 'depreciated';
+            return 'deprecated';
         } elseif ($this->isWarning()) {
             return 'Warning';
         } else {
@@ -579,7 +579,7 @@
             }
             $html->pushContent($list);
         }
         //only print depreciated if debug is 2 or higher
         if (DEBUG < 2 && $this->isDepreciated()) {
             $html=false;
         }
@@ -78,11 +78,11 @@
      * As this is a singleton class, you should never call this.
      */
-    //fixed depreciated dynamic typing
+    // fixed deprecated dynamic typing
     public $_handlers;
     public $_fatal_handler;
@@ -579,7 +579,7 @@
             $html->pushContent($list);
         }
-        //only print depreciated if debug is 2 or higher
+        // only print deprecated if debug is 2 or higher
         if (DEBUG < 2 && $this->isDepreciated()) {
             $html=false;

Modified: trunk/pgsrc/ReleaseNotes
===================================================================